@@ -1,6 +1,6 @@
-#$Id: TigerHash.pm 665 2010-11-26 23:25:14Z pro $ $URL: svn://svn.setun.net/dcppp/trunk/TigerHash/lib/Net/DirectConnect/TigerHash.pm $
+#$Id: TigerHash.pm 752 2011-03-06 22:01:08Z pro $ $URL: svn://svn.setun.net/dcppp/trunk/TigerHash/lib/Net/DirectConnect/TigerHash.pm $
 package Net::DirectConnect::TigerHash;
-our $VERSION = '0.04';# . '_' . ( split( ' ', '$Revision: 665 $' ) )[1];
+our $VERSION = '0.05';# . '_' . ( split( ' ', '$Revision: 752 $' ) )[1];
 use 5.006001;
 use strict;
 use warnings;
@@ -26,6 +26,10 @@ Net::DirectConnect::TigerHash - Perl extension for calculating tiger hashes from
   print tthfile('/etc/passwd'); #base32 encoded
   print tthfile('__NOT_eXisted_file___'); #undef
 
+
+ cmdline usage:
+  perl -MNet::DirectConnect::TigerHash -e "print map { Net::DirectConnect::TigerHash::tthfile($_) . qq{ $_\n} } @ARGV" your files here
+
 =head1 DESCRIPTION
 
  ported from eiskaltdc
